package com.bursie.harvester.logic;

import java.util.Arrays;
import java.util.HashSet;
import java.util.Set;

/**
 * A class for handling the removal of stop words. According to http://www.ranks.nl/resources/stopwords.html,
 * this is the list that Google uses.
 */
public class StopWords {

    private Set<String> stopWords;

    public StopWords() {
        String[] words = {"I", "a", "about", "an", "are", "as", "at", "be", "by", "com", "de", "en", "for", "from",
                "how", "in", "is", "it", "la", "of", "on", "or", "that", "the", "this", "to", "was", "what", "when",
                "where", "who", "will", "with", "und", "the", "www"};
        stopWords = new HashSet<String>();
        stopWords.addAll(Arrays.asList(words));
    }

    /**
     * Cleans the input from all stop words
     *
     * @param input An input string which might contain stop words
     * @return A String exactly as the input, but without stopwords
     */
    public String removeStopWords(String input) {
        if (input == null) {
            return null;
        }
        String[] tokens = input.split(" ");
        StringBuilder output = new StringBuilder();
        for (String token : tokens) {
            if (!stopWords.contains(token)) {
                output.append(token);
                output.append(" ");
            }
        }
        if (output.length() > 0) {
            output.deleteCharAt(output.length() - 1);
        }
        return output.toString();
    }
}
