package com.bursie.harvester.web;

import com.bursie.harvester.logic.KeywordExpert;
import com.bursie.harvester.logic.Word;
import javax.servlet.RequestDispatcher;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.util.List;

/**
 * An MVC Controller class that is responsible for setting the attributes needed by the View.
 */
public class KeywordController extends HttpServlet {
    private static final String SUGGESTED_KEYWORDS = "suggestedKeywords";
    private static final String QUERY_VALUE = "queryValue";
    private static final String QUERY = "query";

    /**
     * Handles GET requests. Sets attributes needed by the View, and forwards the request to the view. Uses the
     * KeywordExpert to find the related keywords.
     *
     * @param request  A httpServletRequest
     * @param response A httpServletResponse
     * @throws IOException
     * @throws ServletException
     */
    public void doGet(HttpServletRequest request,
                      HttpServletResponse response)
            throws IOException, ServletException {
        String queryParam = request.getParameter(QUERY);
        String queryValue = queryParam;

        if (queryValue == null) {
            queryValue = "";   // displayed in the search field when we enter the harvester the first time
        }

        KeywordExpert keywordExpert = KeywordExpert.getDefaultKeywordExpert();
        List<Word> suggestedKeywords = keywordExpert.getSuggestedKeywords(queryParam);

        request.setAttribute(SUGGESTED_KEYWORDS, suggestedKeywords);
        request.setAttribute(QUERY_VALUE, queryValue);

        RequestDispatcher view = request.getRequestDispatcher("WEB-INF/search.jsp");
        view.forward(request, response);
    }

}
